package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.IpnLogMapper;
import com.ruoyi.system.domain.IpnLog;
import com.ruoyi.system.service.IIpnLogService;

/**
 * IpnLogService业务层处理
 * 
 * @author ruoyi
 * @date 2023-11-22
 */
@Service
public class IpnLogServiceImpl extends ServiceImpl<BaseMapper<IpnLog>,IpnLog> implements IIpnLogService
{
    @Autowired
    private IpnLogMapper ipnLogMapper;

    /**
     * 查询IpnLog
     * 
     * @param id IpnLog主键
     * @return IpnLog
     */
    @Override
    public IpnLog selectIpnLogById(Long id)
    {
        return ipnLogMapper.selectIpnLogById(id);
    }

    /**
     * 查询IpnLog列表
     * 
     * @param ipnLog IpnLog
     * @return IpnLog
     */
    @Override
    public List<IpnLog> selectIpnLogList(IpnLog ipnLog)
    {
        return ipnLogMapper.selectIpnLogList(ipnLog);
    }

    /**
     * 新增IpnLog
     * 
     * @param ipnLog IpnLog
     * @return 结果
     */
    @Override
    public int insertIpnLog(IpnLog ipnLog)
    {
        return ipnLogMapper.insertIpnLog(ipnLog);
    }

    /**
     * 修改IpnLog
     * 
     * @param ipnLog IpnLog
     * @return 结果
     */
    @Override
    public int updateIpnLog(IpnLog ipnLog)
    {
        return ipnLogMapper.updateIpnLog(ipnLog);
    }

    /**
     * 批量删除IpnLog
     * 
     * @param ids 需要删除的IpnLog主键
     * @return 结果
     */
    @Override
    public int deleteIpnLogByIds(Long[] ids)
    {
        return ipnLogMapper.deleteIpnLogByIds(ids);
    }

    /**
     * 删除IpnLog信息
     * 
     * @param id IpnLog主键
     * @return 结果
     */
    @Override
    public int deleteIpnLogById(Long id)
    {
        return ipnLogMapper.deleteIpnLogById(id);
    }
}
